@@ -14,6 +14,7 @@
 #' @param second a vector or list of quoted continuous variables for which the \code{FUN2} should be applied
 #' @param row_wise how to calculate percentages for factor variables when \code{splitby != NULL}: if \code{FALSE} calculates percentages by variable within groups; if \code{TRUE} calculates percentages across groups for one level of the factor variable.
 #' @param test logical; if set to \code{TRUE} then the appropriate bivariate tests of significance are performed if splitby has more than 1 level. A message is printed when the variances of the continuous variables being tested do not meet the assumption of Homogeneity of Variance (using Breusch-Pagan Test of Heteroskedasticity) and, therefore, the argument `var.equal = FALSE` is used in the test.
+#' @param param logical; if set to \code{TRUE} then the appropriate parametric bivariate tests of significance are performed (if `test = TRUE`). For continuous variables, it is a t-test or ANOVA (depending on the number of levels of the group). If set to \code{FALSE}, the Kruskal-Wallis Rank Sum Test is performed for the continuous variables. Either way, the chi-square test of independence is performed for categorical variables.
 #' @param header_labels a character vector that renames the header labels (e.g., the blank above the variables, the p-value label, and test value label).
 #' @param type what is displayed in the table; a string or a vector of strings. Two main sections can be inputted: 1. if test = TRUE, can write "pvalues", "full", or "stars" and 2. can state "simple" and/or "condense". These are discussed in more depth in the details section below.
 #' @param output how the table is output; can be "text" or "text2" for regular console output or any of \code{kable()}'s options from \code{knitr} (e.g., "latex", "markdown", "pandoc"). A new option, \code{'latex2'}, although more limited, allows the variable name to show and has an overall better appearance.
@@ -72,45 +73,12 @@
 #'        x2 = ifelse(x > 0, 1, 0), z = z)
 #'
 #' @export
-#' @importFrom stats IQR addmargins complete.cases dchisq lm median model.frame oneway.test pt resid sd setNames t.test
+#' @importFrom stats IQR addmargins complete.cases dchisq lm median model.frame oneway.test pt resid sd setNames t.test kruskal.test chisq.test
 #' @importFrom utils write.csv
 #' @importFrom knitr kable
 #' @importFrom dplyr group_by
 #' @importFrom dplyr mutate
 table1 = function(.data, 
-                   ..., 
-                   splitby = NULL, 
-                   FUN = NULL,
-                   FUN2 = NULL,
-                   total = FALSE,
-                   second = NULL,
-                   row_wise = FALSE, 
-                   test = FALSE, 
-                   header_labels = NULL,
-                   type = "pvalues",
-                   output = "text",
-                   rounding_perc = 1,
-                   digits = 1,
-                   var_names = NULL, 
-                   format_number = FALSE,
-                   NAkeep = NULL, 
-                   na.rm = TRUE,
-                   booktabs = TRUE, 
-                   caption = NULL, 
-                   align = NULL,
-                   float = "ht",
-                   export = NULL,
-                   label = NULL){
-  UseMethod("table1", .data)
-}
-
-
-#' @export
-#' @importFrom utils write.csv
-#' @importFrom knitr kable
-#' @importFrom forcats fct_drop
-#' @importFrom dplyr filter
-table1.data.frame = function(.data, 
                   ..., 
                   splitby = NULL, 
                   FUN = NULL,
@@ -119,6 +87,7 @@ table1.data.frame = function(.data,
                   second = NULL,
                   row_wise = FALSE, 
                   test = FALSE, 
+                  param = TRUE,
                   header_labels = NULL,
                   type = "pvalues",
                   output = "text",
@@ -134,6 +103,39 @@ table1.data.frame = function(.data,
                   float = "ht",
                   export = NULL,
                   label = NULL){
+  UseMethod("table1", .data)
+}
+
+
+#' @export
+#' @importFrom utils write.csv
+#' @importFrom knitr kable
+#' @importFrom dplyr filter
+table1.data.frame = function(.data, 
+                             ..., 
+                             splitby = NULL, 
+                             FUN = NULL,
+                             FUN2 = NULL,
+                             total = FALSE,
+                             second = NULL,
+                             row_wise = FALSE, 
+                             test = FALSE, 
+                             param = TRUE,
+                             header_labels = NULL,
+                             type = "pvalues",
+                             output = "text",
+                             rounding_perc = 1,
+                             digits = 1,
+                             var_names = NULL, 
+                             format_number = FALSE,
+                             NAkeep = NULL, 
+                             na.rm = TRUE,
+                             booktabs = TRUE, 
+                             caption = NULL, 
+                             align = NULL,
+                             float = "ht",
+                             export = NULL,
+                             label = NULL){
   
   ###################
   ## Preprocessing ##
@@ -151,12 +153,6 @@ table1.data.frame = function(.data,
   ## checks
   .header_labels(header_labels, format_output)
   
-  ## Deprecation (drop in furniture 2.0.0)
-  if (!is.null(NAkeep)){
-    warning("NAkeep is deprecated. Please use na.rm instead.\nNote that {NAkeep = TRUE} == {na.rm = FALSE}.", 
-            call. = FALSE)
-    na.rm <- !NAkeep
-  }
   ## Not yet deprecated
   #if (!is.null(splitby))
   #  warning("`splitby` is deprecated. Use dplyr::group_by() instead. It's use will continue until furniture 2.0.0")
@@ -180,7 +176,7 @@ table1.data.frame = function(.data,
   ## Functions
   num_fun  <- .summary_functions1(FUN, format_number, digits)
   num_fun2 <- .summary_functions2(FUN2, format_number, digits)
-
+  
   ########################
   ## Variable Selecting ##
   ########################
@@ -195,7 +191,7 @@ table1.data.frame = function(.data,
   }
   
   ## Splitby or group_by
-  if (is.null(attr(.data, "vars")) && is.null(attr(.data, "groups"))){
+  if (is.null(attr(.data, "groups"))){
     
     ### Splitby Variable (adds the variable to d as "split")
     if (!is.null(splitby))
@@ -220,24 +216,18 @@ table1.data.frame = function(.data,
     if (length(which(names(d) %in% splitby_)) != 0){
       d <- d[, -which(names(d) %in% splitby_), drop = FALSE]
     }
-
+    
   } else {
     
-    ## Working around different versions of dplyr with group_by()
-    ## Older (0.7.6) uses "vars": produces the grouping name
-    ## Developmental one (0.7.9.9000) uses "groups" but it produces a nested table
-    groups <- attr(.data, "vars")
-    if (is.null(groups))
-      groups <- attr(.data, "groups") %>% names(.)
-    if (groups[length(groups)] == ".rows")
-      groups <- groups[-length(groups)]
+    groups <- attr(.data, "groups") %>% names(.)
+    groups <- groups[-length(groups)]
     
     message(paste0("Using dplyr::group_by() groups: ", paste(groups, collapse = ", ")))
     
     if (length(groups) == 1){
       d$split <- factor(.data[[groups]])
     } else {
-      interacts <- interaction(.data[groups], sep = "_")
+      interacts <- interaction(.data[groups], sep = "-")
       d$split <- factor(interacts)
     }
     ## For print method
@@ -251,14 +241,14 @@ table1.data.frame = function(.data,
       d <- d[, -which(names(d) %in% groups), drop = FALSE]
     }
   }
-
+  
   
   ## Remove missing values?
   if (isTRUE(na.rm))
     d <- d[complete.cases(d), , drop = FALSE]
   if (nrow(d) == 0)
     stop("No non-missing values in data frame with `na.rm = TRUE`", call. = FALSE)
-
+  
   
   ## Splitby variable needs to have more than one level when test = TRUE
   if (test & length(levels(d$split))>1){
@@ -268,11 +258,9 @@ table1.data.frame = function(.data,
   }
   
   ## Does each variable have at least two levels?
-  if (! .more_than_one_value(d)){
-    warning(paste("Not all variables have at least 2 unique values.",
-                  "Functionality of the following will be limited:\n",
-                  " -- `type = 'condense'` will not work\n",
-                  " -- `test = TRUE` will not work"), 
+  if ((! .more_than_one_value(d)) & test){
+    test = FALSE
+    warning("Not all variables have at least 2 unique values. Cannot do tests...", 
             call. = FALSE)
   }
   
@@ -288,11 +276,11 @@ table1.data.frame = function(.data,
   ## Observations and Header Labels ##
   ####################################
   N <- .obs_header(d, f1, format_output, test, output, header_labels, total)
-
+  
   ######################
   ## Summarizing Data ##
   ######################
-  summed <- table1_summarizing(d, num_fun, num_fun2, second, row_wise, test, NAkeep, total)
+  summed <- table1_summarizing(d, num_fun, num_fun2, second, row_wise, test, param, NAkeep, total)
   tab    <- summed[[1]]
   tab2   <- summed[[2]]
   tests  <- summed[[3]]
@@ -304,7 +292,7 @@ table1.data.frame = function(.data,
   ## Not Condensed or Condensed
   if (!condense){
     tabZ <- table1_format_nocondense(d, tab, tab2, tests, test, NAkeep, rounding_perc, 
-                                     format_output, second, nams, simple, output, f1, total)
+                                     format_output, second, nams, simple, output, f1, total, param)
   } else if (condense){
     tabZ <- table1_format_condense(d, tab, tab2, tests, test, NAkeep, rounding_perc, 
                                    format_output, second, nams, simple, output, f1, total)
@@ -341,22 +329,24 @@ table1.data.frame = function(.data,
     class(final_l) <- c("table1")
     cat("\n", caption)
     return(final_l)
-
-  ## Custom Latex Output
+    
+    ## Custom Latex Output
   } else if (output %in% "latex2"){
     if (is.null(align)){
       l1 <- dim(final)[2]
       align <- c("l", rep("c", (l1-1)))
     }
-    tab <- to_latex(final, caption, align, len = length(levels(d$split)), splitting, float, booktabs, label)
+    tab <- to_latex(final, caption, align, len = length(levels(d$split)), 
+                    splitting, float, booktabs, label, total)
     tab
-  ## Output from kable  
+    ## Output from kable  
   } else if (output %in% c("latex", "markdown", "html", "pandoc", "rst")){
-    kab <- knitr::kable(final, format=output,
-                 booktabs = booktabs,
-                 caption = caption,
-                 align = align,
-                 row.names = FALSE)
+    kab <- knitr::kable(final, 
+                        format=output,
+                        booktabs = booktabs,
+                        caption = caption,
+                        align = align,
+                        row.names = FALSE)
     return(kab)
   } else {
     stop(paste("Output of type", output, "not recognized"))
@@ -413,7 +403,7 @@ print.table1 <- function(x, ...){
       dim(x4)[2] - 1
     first_width <- sum(ifelse(unlist(max_col_width3) > nchar("  "), unlist(max_col_width3), nchar("  ")))
   }
-
+  
   
   ## Print top border
   cat("\n\u2500")
@@ -434,8 +424,8 @@ print.table1 <- function(x, ...){
     if (attr(x, "output") == "text2"){
       ## Special "text2" formatting
       x4 <- rbind(x[[1]][1,],
-                 sapply(max_col_width, function(x) paste0(rep("-", times = x), collapse = "")),
-                 x[[1]][2:dim(x[[1]])[1], ])
+                  sapply(max_col_width, function(x) paste0(rep("-", times = x), collapse = "")),
+                  x[[1]][2:dim(x[[1]])[1], ])
       print(x4, ..., row.names = FALSE, right = FALSE)
     } else {
       print(x[[1]], ..., row.names = FALSE, right = FALSE)
@@ -460,4 +450,4 @@ as.data.frame.table1 <- function(x, row.names = NULL, optional = FALSE, ...,
   as.data.frame.list(x) %>%
     setNames(., gsub("Table1\\.", "", names(.)))
   
-}
+}
\ No newline at end of file
